//--------------------------------------------------------------------------------------------------
//	Author:	P.Roman, Curtea de Arges, Romania
//
// 	Date		  Version	Description
//	------------------------------------------------------------------------------------------------
//	20220217	1.0.0	  First release
//  20220219  1.1.0   Modified parameterlist of constructor. Delayed reaction of sensor implemented.
//
//	ARDUINO program for sending the status of 6 IR-sensors directly to 6 output channels.
//
//  ------------------------------------------------------------------------------------------------
//  PINS:
//
//  reserved        0 // reserved for Serial communication
//  reserved        1 // reserved for Serial communication
//
//  other pins see pin declarations below
//
//--------------------------------------------------------------------------------------------------
#define DEBUG	// comment out if serial output is no longer needed for debug purposes

#include <IRSensor.h>

//==================================================================================================
//======== User may change the parameters below ====================================================
//==================================================================================================
const byte nSensors             = 6;                          // Number of sensors 
const byte pinSensors[nSensors] = {A0, A1, A2, A3, A4, A5};   // Pin Sensors (must be analog pins)
const byte pinLeds[nSensors]    = { 2,  3,  4,  5,  6,  7};   // IR-leds
const byte pinOuts[nSensors]    = { 8,  9, 10, 11, 12, 13};   // Output channels
const byte tresholds[nSensors]  = {90, 90, 90, 90, 90, 90};   // treshold for detection (%)
const byte extraOnCycles        = 0;                          // no delay
const byte extraOffCycles       = 0;                          // no delay
const byte period               = 20;                         // led on/off cycle for all leds [ms]
//==================================================================================================

IRSensor **theIRSensors = new IRSensor*[nSensors];

#ifdef DEBUG
void serialReport() {
  const unsigned long refreshInterval = 1000;  // refresh serial output every 2 seconds
	static unsigned long lastRefresh = 0;
	unsigned long now = millis();
	if ((now - lastRefresh) > refreshInterval) {
		Serial.println(F("Sensor----Value------"));
		for (byte i = 0; i < nSensors; i++) {
			Serial.print(i); Serial.print(F("          ")); Serial.println(theIRSensors[i]->isON());
		}
    lastRefresh = now;
	}
}	
#endif

void setup() {
#ifdef DEBUG
  Serial.begin(115200);
  Serial.println(F("-----------------------------------------------------"));
  Serial.println(F("----- Arduino 6-fold modulated IR-Sensor 1.1.0 ------"));
  Serial.println(F("-----------------------------------------------------"));
  Serial.println(F(""));
#endif
  for (byte i = 0; i < nSensors; i++) {
		theIRSensors[i] = new IRSensor(pinLeds[i], pinSensors[i], tresholds[i], extraOnCycles, extraOffCycles, period);
		pinMode(pinOuts[i], OUTPUT);												// e.g. connect to S88-Ground-module
		digitalWrite(pinOuts[i], HIGH);                     // active LOW, so initially HIGH
	}
} 

void loop() {
  for (byte i = 0; i < nSensors; i++) {
    theIRSensors[i]->update();
    digitalWrite(pinOuts[i], !theIRSensors[i]->isON()); // active LOW
	}
#ifdef DEBUG
	serialReport();
#endif
}
